@@ -293,7 +293,7 @@ def view_account(db,account):
     if check(db)==False:
         return
     task_start()
-    masterpassword=getpass.getpass(' Enter Password:')
+    masterpassword=getpass.getpass(' Enter Master Password:')
     masterkey=get_masterpassword(db)
     masterkey=en(masterpassword,masterkey)
     connect=sqlite3.connect(db)
@@ -305,9 +305,14 @@ def view_account(db,account):
         print(' Password:',en(output[0][2],masterkey))
         if output[0][3].lower() != 'null':
             print(' Website:',output[0][3])
+
+        print('\n Generated Password:-\n',en(output[0][2],masterkey))
+
+        if output[0][3].lower() != 'null':
             choice=input('\n Do you want to open website in Browser?(Y/N):')
             if choice.lower() == 'y':
                 webbrowser.open(output[0][3])
+
         task_end()
     except:
         print(" Invalid Data supplied!")
@@ -340,6 +345,12 @@ def export(db):
 def importt(db):
     db=valid_db(db)
     task_start()
+    file=input(' Enter csv file to import:')
+    if os.path.exists(file) is False:
+        print('File Not Found!')
+        task_fail()
+        exit(1)
+
     password=getpass.getpass(' Enter Secret Token:')
     if len(password)%32 != 0:
         print('\n\a Invalid Token!!!')
@@ -385,7 +396,7 @@ def importt(db):
                         password varchar(640),
                         website varchar(200)
                         )''')
-    file=input(' Enter csv file to import:')
+
     os.chdir('..')
     try:
         with open(file,newline='') as csvfile:
